# abqcy

Write Abaqus Subroutines in Cython

- GitHub repository: [https://github.com/haiiliin/abqcy](https://github.com/haiiliin/abqcy)
- PyPI: [https://pypi.org/project/abqcy](https://pypi.org/project/abqcy)
- Documentation: [https://abqcy.readthedocs.io](https://abqcy.readthedocs.io)
- Read the Docs: [https://readthedocs.org/projects/abqcy](https://readthedocs.org/projects/abqcy)
- Bug Report: [ [https://github.com/haiiliin/abqcy/issues](https://github.com/haiiliin/abqcy/issues)
